<?php
/**
 * @file
 * Drop Jobs Candidate Rules integration.
 */

/**
 * Access callback.
 *
 * @see drop_jobs_candidate_rules_event_info()
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_rules_access($type, $name) {
  if ($type == 'event' || $type == 'condition') {
    return user_access('administer drop_jobs_candidate');
  }
}

/**
 * Implements hook_rules_event_info().
 *
 * Defines rules events.
 */
function drop_jobs_candidate_rules_event_info() {
  $events = array();

  // For the sake of convenience.
  $defaults = array(
    'group' => t('Drop Jobs Candidate'),
    'access callback' => 'drop_jobs_candidate_rules_access',
    'variables' => array(
      'profile' => array(
        'label' => t('Candidate profile object'),
        'type' => 'profile2',
        'skip save' => TRUE,
      ),
    ),
  );

  // Candidate résumé becomes complete.
  $events['drop_jobs_candidate_complete'] = array(
    'label' => t('Candidate completes his résumé.'),
    ) + $defaults;

  // Candidate résumé becomes incomplete.
  $events['drop_jobs_candidate_incomplete'] = array(
    'label' => t('Candidate un-completes his résumé.'),
    ) + $defaults;

  // Candidate résumé becomes active.
  $events['drop_jobs_candidate_active'] = array(
    'label' => t('Résumé set to active.'),
    ) + $defaults;

  // Candidate résumé becomes inactive.
  $events['drop_jobs_candidate_inactive'] = array(
    'label' => t('Résumé set to inactive.'),
    ) + $defaults;

  return $events;
}

/**
 * Implements hook_rules_condition_info().
 */
function drop_jobs_candidate_rules_condition_info() {
  $conditions = array();

  // For convenience.
  $defaults = array(
    'group' => t('Drop Jobs Candidate'),
    'parameter' => array(
      'profile' => array(
        'label' => t('Candidate profile object'),
        'type' => 'profile2',
        'skip save' => TRUE,
      ),
    ),
  );

  $conditions['drop_jobs_candidate_active'] = array(
    'label' => t("Check whether a given candidate's résumé is active"),
    'base' => 'drop_jobs_candidate_condition_active',
    ) + $defaults;

  $conditions['drop_jobs_candidate_inactive'] = array(
    'label' => t("Check whether a given candidate's résumé is inactive"),
    'base' => 'drop_jobs_candidate_condition_inactive',
    ) + $defaults;

  $conditions['drop_jobs_candidate_complete'] = array(
    'label' => t("Check whether a given candidate's résumé is complete"),
    'base' => 'drop_jobs_candidate_condition_complete',
    ) + $defaults;

  $conditions['drop_jobs_candidate_incomplete'] = array(
    'label' => t("Check whether a given candidate's résumé is incomplete"),
    'base' => 'drop_jobs_candidate_condition_incomplete',
    ) + $defaults;

  return $conditions;
}

/**
 * Implements hook_rules_action_info().
 */
function drop_jobs_candidate_rules_action_info() {
  $actions = array();

  // For convenience.
  $defaults = array(
    'group' => t('Drop Jobs Candidate'),
    'access callback' => 'drop_jobs_candidate_rules_access',
    'parameter' => array(
      'profile' => array(
        'type' => 'profile2',
        'label' => t('Profile object'),
        'save' => FALSE,
      ),
    ),
  );

  // Mark a résumé as active.
  $actions['drop_jobs_candidate_active'] = array(
    'label' => t('Make a résumé as active'),
    'base' => 'drop_jobs_candidate_action_active',
    ) + $defaults;

  // Mark a résumé as inactive.
  $actions['drop_jobs_candidate_inactive'] = array(
    'label' => t('Make a résumé as inactive'),
    'base' => 'drop_jobs_candidate_action_inactive',
    ) + $defaults;

  // Mark a résumé as complete.
  $actions['drop_jobs_candidate_complete'] = array(
    'label' => t('Make a résumé as complete'),
    'base' => 'drop_jobs_candidate_action_complete',
    ) + $defaults;

  // Mark a résumé as incomplete.
  $actions['drop_jobs_candidate_incomplete'] = array(
    'label' => t('Make a résumé as incomplete'),
    'base' => 'drop_jobs_candidate_action_incomplete',
    ) + $defaults;

  return $actions;
}

/**
 * Rules condition callback.
 * Checks whether a given profile is active.
 *
 * @see drop_jobs_candidate_rules_condition_info()
 */
function drop_jobs_candidate_condition_active(Profile $profile) {
  return drop_jobs_candidate_resume_is_active($profile);
}

/**
 * Rules condition callback.
 * Checks whether a given profile is inactive.
 *
 * @see drop_jobs_candidate_rules_condition_info()
 */
function drop_jobs_candidate_condition_inactive(Profile $profile) {
  return !drop_jobs_candidate_resume_is_active($profile);
}

/**
 * Rules condition callback.
 * Checks whether a given profile is complete.
 *
 * @see drop_jobs_candidate_rules_condition_info()
 */
function drop_jobs_candidate_condition_complete(Profile $profile) {
  return drop_jobs_candidate_resume_is_complete($profile);
}

/**
 * Rules condition callback.
 * Checks whether a given profile is incomplete.
 *
 * @see drop_jobs_candidate_rules_condition_info()
 */
function drop_jobs_candidate_condition_incomplete(Profile $profile) {
  return !drop_jobs_candidate_resume_is_complete($profile);
}

/**
 * Rules action callback.
 * Marks a given profile as active.
 *
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_action_active(Profile $profile) {
  return drop_jobs_candidate_resume_set_active($profile);
}

/**
 * Rules action callback.
 * Marks a given profile as inactive.
 *
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_action_inactive(Profile $profile) {
  return drop_jobs_candidate_resume_set_inactive($profile);
}

/**
 * Rules action callback.
 * Marks a given profile as complete.
 *
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_action_complete(Profile $profile) {
  return drop_jobs_candidate_resume_set_complete($profile);
}

/**
 * Rules action callback.
 * Marks a given profile as incomplete.
 *
 * @see drop_jobs_candidate_rules_action_info()
 */
function drop_jobs_candidate_action_incomplete(Profile $profile) {
  return drop_jobs_candidate_resume_set_incomplete($profile);
}